@@ -1,4 +1,4 @@
-# Copyright (C) 2013 - 2019  Metrum Research Group, LLC
+# Copyright (C) 2013 - 2019  Metrum Research Group
 #
 # This file is part of mrgsolve.
 #
@@ -98,22 +98,23 @@ env_update <- function(.x,...,.dots=list()) {
 ##' @keywords internal
 ##' @export
 cama <- function(mod,fn="cama",...) {
-  object_exists(fn, mod@envir, "function", inherits=FALSE)
-  f <- get(fn, mod@envir, inherits=FALSE)
-  mod %>% update(...) %>% f
+  stop("this function is deprecated.")
+  # object_exists(fn, mod@envir, "function", inherits=FALSE)
+  # f <- get(fn, mod@envir, inherits=FALSE)
+  # mod %>% update(...) %>% f
 }
 
 
-param_in_env <- function(x) {
-  p <- as.list(param(x))
-  list2env(p[setdiff(names(p),ls(x@envir))],envir=x@envir)
-}
-
-param_out_env <- function(x) {
-  what <- intersect(names(param(x)),ls(envir=x@envir))
-  rm(list=what,envir=x@envir)
-  return(invisible(x))
-}
-
+# param_in_env <- function(x) {
+#   p <- as.list(param(x))
+#   list2env(p[setdiff(names(p),ls(x@envir))],envir=x@envir)
+# }
+# 
+# param_out_env <- function(x) {
+#   what <- intersect(names(param(x)),ls(envir=x@envir))
+#   rm(list=what,envir=x@envir)
+#   return(invisible(x))
+# }
+# 
 
 
