@@ -33,8 +33,9 @@ test_that("mrgsims class", {
 
 test_that("plot from character", {
   out <- mrgsolve::house() %>% mrgsim()
-  pl1 <- out %>%  plot(" CENT DV, CP")
-  pl2 <- out %>% plot(CENT+DV+CP~time)
-  expect_equal(pl1,pl2)
+  pl1 <- plot(out, " CENT DV, CP")
+  pl2 <- plot(out, CENT+DV+CP~time)
+  expect_is(pl1,"trellis")
+  expect_is(pl2,"trellis")
 })
 
